@@ -200,7 +200,7 @@ NULL
 # The following ensures that the DLL is unloaded when the package is unloaded.
 # See http://r-pkgs.had.co.nz/src.html
 .onUnload <- function(libpath) {
- library.dynam.unload("GMCM", libpath)
+ library.dynam.unload("GMCM", libpath) # nocov
 }
 
 # 6f037e235ba745d55fea4baa9f32caf64ce2d336ac431578a4ce67ee6e1aebf2
